[PC-BSD Commits] r17710 - pcbsd/current/src-qt4/pc-installgui
svn at pcbsd.org
svn at pcbsd.org
Wed Jul 11 06:56:11 PDT 2012
Author: kris
Date: 2012-07-11 13:56:10 +0000 (Wed, 11 Jul 2012)
New Revision: 17710
Modified:
pcbsd/current/src-qt4/pc-installgui/installer.cpp
pcbsd/current/src-qt4/pc-installgui/wizardFreeBSD.ui
Log:
Rename PC-BSD Server -> TrueOS
Modified: pcbsd/current/src-qt4/pc-installgui/installer.cpp
===================================================================
--- pcbsd/current/src-qt4/pc-installgui/installer.cpp 2012-07-11 13:14:35 UTC (rev 17709)
+++ pcbsd/current/src-qt4/pc-installgui/installer.cpp 2012-07-11 13:56:10 UTC (rev 17710)
@@ -620,9 +620,9 @@
{
// Init the desktop selector
wheelIcons << ":modules/images/freebsd.png" << ":/modules/images/pcbsd-server.png" << ":/PCBSD/images/kde.png" << ":/PCBSD/images/lxde.png" << ":/PCBSD/images/gnome.png" << ":/PCBSD/images/xfce.png";
- wheelName << "FreeBSD Server" << "PC-BSD Server" << "KDE" << "LXDE" << "GNOME" << "XFCE";
+ wheelName << "FreeBSD Server" << "TrueOS" << "KDE" << "LXDE" << "GNOME" << "XFCE";
wheelDesc << tr("FreeBSD is an advanced operating system for modern server, desktop, and embedded computer platforms. FreeBSD's code base has undergone over thirty years of continuous development, improvement, and optimization.") \
- << tr("The PC-BSD Server is a console based system running FreeBSD. It includes command-line versions of The Warden jail management, PBI manager, system updater and other helpful utilities for system administrators.") \
+ << tr("TrueOS is a console based server running FreeBSD. It includes command-line versions of The Warden jail management, PBI manager, ZFS boot environments (beadm), and other helpful utilities for system administrators.") \
<< tr("KDE is a full-featured desktop environment, which includes support for 3D desktop effects, multiple desktops, and a variety of built-in tools and utilities for both new and power-desktop users.<br><br>* Recommended for higher-end systems with 2GB of RAM or more *") \
<< tr("LXDE is a lightweight desktop, minimalist in nature, with support for multiple-desktops, a system tray, application menu and more.<br><br>* Recommended for netbooks, or lower-end systems * ") \
<< tr("GNOME is a full-featured desktop environment, complete with a large number of integrated utilities and tools for desktop users.") \
@@ -841,7 +841,7 @@
} else {
tmpList << "installType=FreeBSD";
tmpList << "packageType=tar";
// If we are doing PC-BSD server or FreeBSD server
if ( wheelCurItem == wPCSERVER || wheelCurItem == 12 )
tmpList << "installFile=PCBSD-Server.txz";
else
@@ -841,7 +841,7 @@
tmpList << "installType=FreeBSD";
tmpList << "packageType=tar";
- // If we are doing PC-BSD server or FreeBSD server
+ // If we are doing TrueOS server or FreeBSD server
if ( wheelCurItem == wPCSERVER || wheelCurItem == 12 )
tmpList << "installFile=PCBSD-Server.txz";
Modified: pcbsd/current/src-qt4/pc-installgui/wizardFreeBSD.ui
===================================================================
(Binary files differ)
More information about the Commits
mailing list